"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TradeClient = void 0;
const common_sdk_1 = require("@orca-so/common-sdk");
const __1 = require("..");
class TradeClient {
    constructor(ctx, publicKey, data, pda, configid) {
        this.ctx = ctx;
        this.data = data;
        this.publicKey = publicKey;
        this.pda = pda;
        this.configId = configid;
    }
    static getTrade(ctx, configId, tradeId) {
        return __awaiter(this, void 0, void 0, function* () {
            const pda = new __1.PDA(ctx.program.programId, configId);
            const tradePublickey = pda.getTradePDA(tradeId).key;
            const tradeAccount = (yield ctx.program.account.trade.fetch(tradePublickey));
            if (!tradeAccount) {
                throw new Error(`Trade ${tradeId} not found`);
            }
            return new TradeClient(ctx, tradePublickey, tradeAccount, pda, configId);
        });
    }
    release() {
        return __awaiter(this, void 0, void 0, function* () {
            const { sellerAuthority, buyerAuthority, tokenVault, nativeVault } = this.data;
            const _a = yield (0, common_sdk_1.resolveOrCreateATA)(this.ctx.connection, sellerAuthority, this.data.tokenMint, () => this.ctx.fetcher.getTokenAccountRentExempt(), undefined, sellerAuthority), { address: sellerTokenAccount } = _a, createSellerTokenAccountInstruction = __rest(_a, ["address"]);
            const _b = yield (0, common_sdk_1.resolveOrCreateATA)(this.ctx.connection, buyerAuthority, this.data.tokenMint, () => this.ctx.fetcher.getTokenAccountRentExempt(), undefined, sellerAuthority), { address: buyerTokenAccount } = _b, createBuyerTokenAccountInstruction = __rest(_b, ["address"]);
            const tx = (yield this.ctx.ixs.releaseIx({
                offer: this.pda.getOfferPDA(this.data.offerId).key,
                trade: this.publicKey,
                seller: sellerAuthority,
                buyer: buyerAuthority,
                sellerTokenAccount,
                buyerTokenAccount,
                tokenVault,
                nativeVault,
                configRentVault: this.pda.getConfigRentVaultPDA().key,
            }))
                .toTx()
                .prependInstructions([
                createSellerTokenAccountInstruction,
                createBuyerTokenAccountInstruction,
            ]);
            return tx;
        });
    }
    callArbitrator(caller) {
        return __awaiter(this, void 0, void 0, function* () {
            const tx = (yield this.ctx.ixs.callArbitrator({
                escrowConfig: this.data.escrowConfig,
                trade: this.publicKey,
                caller: caller,
            })).toTx();
            return tx;
        });
    }
    resolveDispute(arbitrator, disputeAction, compensationAction) {
        return __awaiter(this, void 0, void 0, function* () {
            // Get or create corressponding token accounts of parties if needed
            const _a = yield (0, common_sdk_1.resolveOrCreateATA)(this.ctx.connection, arbitrator, this.data.tokenMint, () => this.ctx.fetcher.getTokenAccountRentExempt(), undefined, arbitrator), { address: arbitratorTokenAccount } = _a, createArbitratorTokenAccountInstruction = __rest(_a, ["address"]);
            const _b = yield (0, common_sdk_1.resolveOrCreateATA)(this.ctx.connection, this.data.sellerAuthority, this.data.tokenMint, () => this.ctx.fetcher.getTokenAccountRentExempt(), undefined, arbitrator), { address: sellerTokenAccount } = _b, createSellerTokenAccountInstruction = __rest(_b, ["address"]);
            const _c = yield (0, common_sdk_1.resolveOrCreateATA)(this.ctx.connection, this.data.buyerAuthority, this.data.tokenMint, () => this.ctx.fetcher.getTokenAccountRentExempt(), undefined, arbitrator), { address: buyerTokenAccount } = _c, createBuyerTokenAccountInstruction = __rest(_c, ["address"]);
            const escrowConfig = (yield this.ctx.program.account.escrowConfig.fetch(this.data.escrowConfig));
            const _d = yield (0, common_sdk_1.resolveOrCreateATA)(this.ctx.connection, escrowConfig.treasuryPubkey, this.data.tokenMint, () => this.ctx.fetcher.getTokenAccountRentExempt(), undefined, arbitrator), { address: treasuryTokenAccount } = _d, createTreasuryTokenAccountInstruction = __rest(_d, ["address"]);
            const tx = (yield this.ctx.ixs.resolveDispute({
                disputeAction,
                compensationAction,
                escrowConfig: this.data.escrowConfig,
                offer: this.pda.getOfferPDA(this.data.offerId).key,
                trade: this.publicKey,
                treasuryAuthority: escrowConfig.treasuryPubkey,
                arbitratorAuthority: arbitrator,
                treasuryTokenAccount: treasuryTokenAccount,
                arbitartorCert: this.pda.getArbitratorCertPDA(arbitrator).key,
                arbitratorTokenAccount: arbitratorTokenAccount,
                seller: this.data.sellerAuthority,
                sellerTokenAccount: sellerTokenAccount,
                buyer: this.data.buyerAuthority,
                buyerTokenAccount: buyerTokenAccount,
                buyerKycCert: this.pda.getKycCertPDA(this.data.tokenMint, this.data.buyerAuthority).key,
                tokenVault: this.data.tokenVault,
                nativeVault: this.data.nativeVault,
                configRentVault: this.pda.getConfigRentVaultPDA().key,
            }))
                .toTx()
                .prependInstructions([
                createArbitratorTokenAccountInstruction,
                createBuyerTokenAccountInstruction,
                createSellerTokenAccountInstruction,
                createTreasuryTokenAccountInstruction,
            ]);
            return tx;
        });
    }
    cancelBuy(buyer) {
        return __awaiter(this, void 0, void 0, function* () {
            const { escrowConfig, tokenVault, nativeVault, tokenMint } = this.data;
            let escrowConfigAccountdata = (yield this.ctx.program.account.escrowConfig.fetch(escrowConfig));
            if (!escrowConfigAccountdata) {
                throw new Error(`Escrow config ${escrowConfig} not found`);
            }
            const _a = yield (0, common_sdk_1.resolveOrCreateATA)(this.ctx.connection, escrowConfigAccountdata.treasuryPubkey, this.data.tokenMint, () => this.ctx.fetcher.getTokenAccountRentExempt(), undefined, buyer), { address: treasuryTokenAccount } = _a, createTreasuryTokenAccountInstruction = __rest(_a, ["address"]);
            const offerTokenVaultPDA = this.pda.getOfferTokenVaultPDA(this.data.offerId);
            const offerNativeVaultPDA = this.pda.getOfferNativeVaultPDA(this.data.offerId);
            const buyerKycCertPDA = this.pda.getKycCertPDA(tokenMint, buyer);
            const tx = (yield this.ctx.ixs.cancelbuyIx({
                escrowConfig: escrowConfig,
                offer: this.pda.getOfferPDA(this.data.offerId).key,
                trade: this.publicKey,
                treasuryAuthority: escrowConfigAccountdata.treasuryPubkey,
                treasuryTokenAccount: treasuryTokenAccount,
                buyer: buyer,
                buyerKycCert: buyerKycCertPDA.key,
                offerTokenVault: offerTokenVaultPDA.key,
                offerNativeVault: offerNativeVaultPDA.key,
                tradeTokenVault: tokenVault,
                tradeNativeVault: nativeVault,
                configRentVault: this.pda.getConfigRentVaultPDA().key,
            }))
                .toTx()
                .prependInstruction(createTreasuryTokenAccountInstruction);
            return tx;
        });
    }
    refresh() {
        return __awaiter(this, void 0, void 0, function* () {
            const tradeAccount = (yield this.ctx.program.account.trade.fetch(this.publicKey));
            this.data = tradeAccount;
            return this;
        });
    }
}
exports.TradeClient = TradeClient;
