/// <reference types="bn.js" />
import { Connection, PublicKey } from "@solana/web3.js";
import { PDA } from "../pda";
import { CachedContent, CachedValue } from "./fetcher";
import { EscrowConfigData, KycCertData, OfferDataInfo, TokenInfoData, TradeData, TradeDataInfo } from "../types";
import { BN } from "@project-serum/anchor";
export declare class EscrowFetcher {
    private readonly fetcher;
    pda: PDA;
    connection: Connection;
    constructor(connection: Connection, pda: PDA, cache?: Record<string, CachedContent<CachedValue>>);
    getConfigData(): Promise<EscrowConfigData | null>;
    getConfigAddress(): PublicKey;
    getTradeInfo(tradeId: BN): Promise<TradeDataInfo | null>;
    getTrades(startTradeId: number, endTradeId?: number): Promise<(TradeData | null)[]>;
    getTradesByStatus(tradeStatus: object): Promise<TradeDataInfo[]>;
    getTradesByBuyerAddress(address: PublicKey): Promise<TradeDataInfo[]>;
    getTradesBySellerAddress(address: PublicKey): Promise<TradeDataInfo[]>;
    getOffersByStatus(offerStatus: object): Promise<OfferDataInfo[]>;
    getOffersByMarkerAddress(address: PublicKey): Promise<OfferDataInfo[]>;
    getOffer(offerId: BN): Promise<OfferDataInfo | null>;
    getOffers(startOfferId: number, endOfferId?: number): Promise<OfferDataInfo[]>;
    getAllTradesOfAnOffer(offerId: BN): Promise<TradeDataInfo[]>;
    getAllTrades(): Promise<(TradeData | null)[]>;
    getKYCCertData(tokenMint: PublicKey, userPubkey: PublicKey): Promise<KycCertData | null>;
    getTokenInfoData(tokenMint: PublicKey): Promise<TokenInfoData | null>;
    isArbitrator(userPubkey: PublicKey): Promise<boolean>;
    refreshAll(): Promise<void>;
}
